.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

.. image:: https://github.com/collective/dsgov.migration/actions/workflows/plone-package.yml/badge.svg
    :target: https://github.com/collective/dsgov.migration/actions/workflows/plone-package.yml

.. image:: https://coveralls.io/repos/github/collective/dsgov.migration/badge.svg?branch=main
    :target: https://coveralls.io/github/collective/dsgov.migration?branch=main
    :alt: Coveralls

.. image:: https://codecov.io/gh/collective/dsgov.migration/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/collective/dsgov.migration

.. image:: https://img.shields.io/pypi/v/dsgov.migration.svg
    :target: https://pypi.python.org/pypi/dsgov.migration/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/dsgov.migration.svg
    :target: https://pypi.python.org/pypi/dsgov.migration
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/pyversions/dsgov.migration.svg?style=plastic   :alt: Supported - Python Versions

.. image:: https://img.shields.io/pypi/l/dsgov.migration.svg
    :target: https://pypi.python.org/pypi/dsgov.migration/
    :alt: License


===============
dsgov.migration
===============

A plugin for migratin content for Plone 5 or Plone 6 from Plone exported content in JSON.


Documentation
-------------

In progress.


Installation
------------

Install dsgov.migration by adding it to your buildout::

    [buildout]

    ...

    eggs =
        dsgov.migration


and then running ``bin/buildout``


Authors
-------

- Fabio Santos


Contributors
------------

- Francisco Filho



License
-------

The project is licensed under the GPLv2.
